Learn R Programming

springerQuarantineBooksR (version 0.1.0)

download_springer_book: Function that fetchs the pdf/epub file and saves it in the current directory

Description

download_springer_book Downloads a single book from the Springer open repository.

Usage

download_springer_book(book_spec_title, springer_table, filetype)

Arguments

book_spec_title

The title of the book to be downloaded.

filetype

The file type extension of the books downloaded. Can be either set to 'pdf', 'epub' or 'both'. Default is 'pdf'.

dspringer_table

The table where 'book_spec_title' should be downloaded from.