Learn R Programming

springerQuarantineBooksR (version 0.1.0)

download_springer_book_files: Download all pdf's/epub's in the directories organized by book type

Description

download_springer_book_files This function can receive many arguments that will be used to download books from the Springer open repository.

Usage

download_springer_book_files(
  springer_books_titles = NA,
  destination_folder = "springer_quarantine_books",
  lan = "eng",
  filetype = "pdf"
)

Arguments

springer_books_titles

A list of books to be downloaded, if left empty, it'll download every book.

destination_folder

A folder/path that will be used to save the files.

lan

The language of the downloaded books. Can be either set to 'eng' (English) or 'ger' (German). Default is 'eng'.

filetype

The file type extension of the books downloaded. Can be either set to 'pdf', 'epub' or 'both'. Default is 'pdf'.