download_springer_book_files This function can receive many arguments that will be used to download books from
the Springer open repository.
download_springer_book_files(
springer_books_titles = NA,
destination_folder = "springer_quarantine_books",
lan = "eng",
filetype = "pdf"
)A list of books to be downloaded, if left empty, it'll download every book.
A folder/path that will be used to save the files.
The language of the downloaded books. Can be either set to 'eng' (English) or 'ger' (German). Default is 'eng'.
The file type extension of the books downloaded. Can be either set to 'pdf', 'epub' or 'both'. Default is 'pdf'.